Todistukset | OiRA
Description: Riskinarvioinnista voi saada todistuksen kansallisen OiRA-kumppanin / OiRA-työkalun kehittäjän valitseman toimintamallin mukaan. Kansalliselta OiRA-kumppanilta saa tietoa tällaisten todistusten hyödyistä.

Aiheet

# Todistukset

Riskinarvioinnista voi saada todistuksen kansallisen OiRA-kumppanin / OiRA-työkalun kehittäjän valitseman toimintamallin mukaan. Kansalliselta OiRA-kumppanilta saa tietoa tällaisten todistusten hyödyistä.

Todistuksen hankkiminen

## Tee täysimääräinen riskinarviointi

OiRA tallentaa edistymistäsi riskinarvioinnin ajan. Kun olet arvioinut tietyn määrän riskejä, työkalu ilmoittaa sinulle mahdollisuudesta saada todistus täysimääräisen riskinarvioinnin suorittamisesta. Kukin kansallinen OiRA-kumppani / OiRA-työkalun kehittäjä määrittää kynnysarvon (prosenttiosuuden) riskinarvioinnin ”täysimääräisyydelle”. Todistus on saatavilla näytön vasemmassa reunassa olevan valikon Tila-painikkeesta.

Tilasivu näyttää, että todistus on saatavilla.

## Katsele todistusta ja julkaise se

Kun napsautat painiketta todistuksen näyttämispainiketta, sinua pyydetään antamaan yrityksen nimi, jonka on tarkoitus näkyä todistuksessa. Kansallisten asetusten mukaan sinua voidaan pyytää antamaan lisätietoa sen varmistamiseksi, että todistuksessa on kaikki tiedot, jotka yritykseltäsi tarvitaan.

Anna kaikki todistukseen tarvittavat tiedot

Jos rastitat ruudun ”Julkinen”, näkyviin tulee yksilöllinen linkki (URL) todistukseesi. Kopioi linkki ja jaa se asianomaisten henkilöiden kanssa todisteena riskinarvioinnin suorittamisesta.

Huomautus: Vain tällä sivulla esitettävät tiedot ovat julkisia. Tämä linkki ei ole saatavilla OiRA-verkkosivuston valikosta, sillä se on tarkoitettu vain sinulle. Teoriassa kuitenkin kuka tahansa verkkoa selaava voi nähdä luomasi todistuksen.

Todistuksessa näytetään vain, että olet käsitellyt tietyn määrän riskejä riskinarviointityökalussa, mutta siinä ei anneta muita tietoja. Vain sinä pystyt näkemään nimenomaiset vastaukset, jotka olet antanut riskinarviointia varten käyttäessäsi OiRA-työkalua. Kukaan muu ei näe vastauksiasi.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More